@@ -9,15 +9,16 @@ package com.google.protobuf;
 
 import static com.google.common.truth.Truth.assertThat;
 import static com.google.common.truth.Truth.assertWithMessage;
+import static org.junit.Assert.assertThrows;
 
-import protobuf_unittest.UnittestProto;
-import protobuf_unittest.UnittestProto.ForeignEnum;
-import protobuf_unittest.UnittestProto.TestAllExtensions;
-import protobuf_unittest.UnittestProto.TestAllTypes;
-import protobuf_unittest.UnittestProto.TestEmptyMessage;
-import protobuf_unittest.UnittestProto.TestEmptyMessageWithExtensions;
-import protobuf_unittest.UnittestProto.TestPackedExtensions;
-import protobuf_unittest.UnittestProto.TestPackedTypes;
+import proto2_unittest.UnittestProto;
+import proto2_unittest.UnittestProto.ForeignEnum;
+import proto2_unittest.UnittestProto.TestAllExtensions;
+import proto2_unittest.UnittestProto.TestAllTypes;
+import proto2_unittest.UnittestProto.TestEmptyMessage;
+import proto2_unittest.UnittestProto.TestEmptyMessageWithExtensions;
+import proto2_unittest.UnittestProto.TestPackedExtensions;
+import proto2_unittest.UnittestProto.TestPackedTypes;
 import proto3_unittest.UnittestProto3;
 import java.util.List;
 import java.util.Map;
@@ -267,6 +268,17 @@ public class UnknownFieldSetTest {
     }
   }
 
+  @Test
+  public void testMergeFieldFromInvalidEndGroup() {
+    byte[] data = new byte[] {(byte) WireFormat.makeTag(1, WireFormat.WIRETYPE_END_GROUP)};
+    CodedInputStream input = CodedInputStream.newInstance(data);
+
+    UnknownFieldSet.Builder instance = UnknownFieldSet.newBuilder();
+    assertThrows(
+        InvalidProtocolBufferException.class,
+        () -> instance.mergeFieldFrom(input.readTag(), input));
+  }
+
   @Test
   @SuppressWarnings("ModifiedButNotUsed")
   public void testHasField_negative() {
