@@ -592,7 +592,7 @@ class GeneratedClassTest extends TestBase
         $arr = array(1, 2.1, "3");
         $m->setRepeatedInt32($arr);
         $this->assertTrue($m->getRepeatedInt32() instanceof RepeatedField);
-        $this->assertSame("Google\Protobuf\Internal\RepeatedField",
+        $this->assertSame("Google\Protobuf\RepeatedField",
                           get_class($m->getRepeatedInt32()));
         $this->assertSame(3, count($m->getRepeatedInt32()));
         $this->assertSame(1, $m->getRepeatedInt32()[0]);
@@ -1943,15 +1943,15 @@ class GeneratedClassTest extends TestBase
         $this->assertEquals('     */', array_pop($commentLines));
         $docComment = implode("\n", $commentLines);
         // test special characters
-        $this->assertStringContainsString(";,/?:&=+$-_.!~*'()", $docComment);
+        $this->assertContains(";,/?:&=+$-_.!~*'()", $docComment);
         // test open doc comment
-        $this->assertStringContainsString('/*', $docComment);
+        $this->assertContains('/*', $docComment);
         // test escaped closed doc comment
-        $this->assertStringNotContainsString('*/', $docComment);
-        $this->assertStringContainsString('{@*}', $docComment);
+        $this->assertNotContains('*/', $docComment);
+        $this->assertContains('{@*}', $docComment);
         // test escaped at-sign
-        $this->assertStringContainsString('\@foo', $docComment);
+        $this->assertContains('\@foo', $docComment);
         // test forwardslash on new line
-        $this->assertStringContainsString("* /\n", $docComment);
+        $this->assertContains("* /\n", $docComment);
     }
 }
