@@ -4,15 +4,16 @@ namespace google {
 namespace protobuf {
 namespace python {
 
-// This exists solely to cause a build/link time error when both
-// :use_fast_cpp_protos and :use_pure_python are specified in a build.;
+// This exists solely to cause a build/link time error when more than one of
+// :use_upb_protos, :use_fast_cpp_protos and :use_pure_python are specified
+// in a build.;
 
 extern "C" {
 
 // MUST match link_error_pure_python.cc's function signature.
 
 __attribute__((noinline)) __attribute__((optnone)) int
-go_SLASH_build_deps_on_BOTH_use_fast_cpp_protos_AND_use_pure_python() {
+go_SLASH_build_deps_on_multiple_python_proto_backends() {
   return 1;
 }
 
