@@ -8,7 +8,7 @@
 use std::alloc::{alloc, Layout};
 
 #[no_mangle]
-extern "C" fn __pb_rust_alloc(size: usize, align: usize) -> *mut u8 {
+extern "C" fn proto2_rust_alloc(size: usize, align: usize) -> *mut u8 {
     if size == 0 {
         // A 0-sized layout is legal but the global allocator isn't required to support
         // it so return a dangling pointer instead.
