@@ -47,6 +47,7 @@
 #include "google/protobuf/io/printer.h"
 
 // Must be last.
+#include "google/protobuf/port.h"
 #include "google/protobuf/port_def.inc"
 
 namespace google {
@@ -254,8 +255,10 @@ void FileGenerator::GenerateSharedHeaderCode(io::Printer* p) {
                      {"messages", [&] { GenerateMessageDefinitions(p); }},
                      {"services", [&] { GenerateServiceDefinitions(p); }},
                      {"extensions", [&] { GenerateExtensionIdentifiers(p); }},
-                     {"inline_fns",
-                      [&] { GenerateInlineFunctionDefinitions(p); }},
+                     {"inline_defs",
+                      [&] {
+                        GenerateInlineFunctionDefinitions(p);
+                      }},
                  },
                  R"(
                    $enums$
@@ -272,7 +275,7 @@ void FileGenerator::GenerateSharedHeaderCode(io::Printer* p) {
 
                    $hrule_thick$
 
-                   $inline_fns$
+                   $inline_defs$
 
                    // @@protoc_insertion_point(namespace_scope)
                  )");
@@ -1166,7 +1169,7 @@ void FileGenerator::GenerateReflectionInitializationCode(io::Printer* p) {
   }
 
   if (!message_generators_.empty()) {
-    std::vector<std::pair<size_t, size_t>> offsets;
+    std::vector<size_t> offsets;
     offsets.reserve(message_generators_.size());
 
     p->Emit(
@@ -1181,9 +1184,8 @@ void FileGenerator::GenerateReflectionInitializationCode(io::Printer* p) {
              [&] {
                int offset = 0;
                for (size_t i = 0; i < message_generators_.size(); ++i) {
-                 message_generators_[i]->GenerateSchema(p, offset,
-                                                        offsets[i].second);
-                 offset += offsets[i].first;
+                 message_generators_[i]->GenerateSchema(p, offset);
+                 offset += offsets[i];
                }
              }},
         },
@@ -1651,6 +1653,7 @@ void FileGenerator::GenerateLibraryIncludes(io::Printer* p) {
   if (HasGeneratedMethods(file_, options_)) {
     IncludeFile("third_party/protobuf/generated_message_tctable_decl.h", p);
   }
+
   IncludeFile("third_party/protobuf/generated_message_util.h", p);
   IncludeFile("third_party/protobuf/metadata_lite.h", p);
 
@@ -1679,6 +1682,9 @@ void FileGenerator::GenerateLibraryIncludes(io::Printer* p) {
     if (HasStringPieceFields(file_, options_)) {
       IncludeFile("third_party/protobuf/string_piece_field_support.h", p);
     }
+    if (HasRegularStringFields(file_, options_)) {
+      IncludeFileAndExport("third_party/protobuf/string_view_migration.h", p);
+    }
   }
   if (HasCordFields(file_, options_)) {
     p->Emit(R"(
@@ -1690,7 +1696,7 @@ void FileGenerator::GenerateLibraryIncludes(io::Printer* p) {
     IncludeFileAndExport("third_party/protobuf/map_type_handler.h", p);
     if (HasDescriptorMethods(file_, options_)) {
       IncludeFile("third_party/protobuf/map_entry.h", p);
-      IncludeFile("third_party/protobuf/map_field_inl.h", p);
+      IncludeFile("third_party/protobuf/map_field.h", p);
     } else {
       IncludeFile("third_party/protobuf/map_field_lite.h", p);
     }
